from pymongo.cursor import Cursor as MongoCursor


class Cursor(MongoCursor):

    def __init__(self, bind, collection, filter=None, *args, **kwargs):
        self.bind = bind
        super(Cursor, self).__init__(collection, filter or {}, *args, **kwargs)

    def __getitem__(self, index):
        document = super(Cursor, self).__getitem__(index)
        return self.bind(document)

    def next(self):
        document = super(Cursor, self).__next__()
        return self.bind(document)

    __next__ = next


__all__ = ["Cursor"]



from setuptools import setup


def get_description():
    with open("README.rst") as file:
        return file.read()


setup(
    name="Mongo-Thingy",
    version="0.1.3",
    url="https://github.com/numberly/mongo-thingy",
    license="MIT",
    author="Guillaume Gelin",
    author_email="ramnes@1000mercis.com",
    description="The most Pythonic and friendly-yet-powerful way to use MongoDB",
    long_description=get_description(),
    packages=["mongo_thingy"],
    include_package_data=True,
    zip_safe=False,
    platforms="any",
    install_requires=["thingy>=0.4.0",
                      "pymongo>=3.0"],
    classifiers=[
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Database",
        "Topic :: Software Development :: Libraries :: Python Modules"
    ]
)
